﻿using AspectCore.DynamicProxy;
using HealthMonitor.Core.Common;

namespace HealthMonitor.Core.Pipeline.Aop.Delete
{
    public class AssertValidDeleteHisValue : AopValueBase
    {
        public override async Task Invoke(CacheInterceptorContext context)
        {
            //方法需要存在参数用于生成缓存键和获取实体类型
            if (context.AopContext.Parameters.Length < 2 || context.AopContext.Parameters[0] == null)
            {
                throw new AssertValidException();
            }

            var param = context.AopContext.Parameters[0];
            var entityType = param.GetType();

            context.IsAsyncMethod = context.AopContext.IsAsync();
            context.EntityType = entityType;
            context.RequestId = context.AopContext.Parameters.Length > 2 ? context.AopContext.Parameters[2] + "" : "";

            using (var scope = context.Logger.BeginScope(new Dictionary<string, object> { ["RequestId"] = context.RequestId }))
            using (new CustomizeStopWatch($"删除历史aop[{entityType.Name}]", context.Logger))
            {
                await InvokeNextAsync(context);
            }
        }
    }
}
